@@ -6,7 +6,8 @@ TOOLCHAINS = [
     'mcux',
     'armgcc',
     'lpcx',
-    'xcc'
+    'xcc',
+    'codewarrior'
 ]
 
 
